==> openshift-model-hive-5.12.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterProvisionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterProvisionBuilder extends io.fabric8.openshift.api.model.hive.v1.ClusterProvisionFluentImpl<io.fabric8.openshift.api.model.hive.v1.ClusterProvisionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.ClusterProvision,io.fabric8.openshift.api.model.hive.v1.ClusterProvisionBuilder>{
  public ClusterProvisionBuilder() {
    this(false);
  }
  public ClusterProvisionBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterProvision(), validationEnabled);
  }
  public ClusterProvisionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterProvisionFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterProvisionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterProvisionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterProvision(), validationEnabled);
  }
  public ClusterProvisionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterProvisionFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterProvision instance) {
    this(fluent, instance, false);
  }
  public ClusterProvisionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterProvisionFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterProvision instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterProvisionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterProvision instance) {
    this(instance,false);
  }
  public ClusterProvisionBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterProvision instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.ClusterProvisionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.ClusterProvision build() {
    ClusterProvision buildable = new ClusterProvision(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterProvisionBuilder that = (ClusterProvisionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.3.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterProvisionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterProvisionBuilder extends ClusterProvisionFluentImpl<ClusterProvisionBuilder> implements VisitableBuilder<ClusterProvision,ClusterProvisionBuilder>{
  public ClusterProvisionBuilder() {
    this(false);
  }
  public ClusterProvisionBuilder(Boolean validationEnabled) {
    this(new ClusterProvision(), validationEnabled);
  }
  public ClusterProvisionBuilder(ClusterProvisionFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterProvisionBuilder(ClusterProvisionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterProvision(), validationEnabled);
  }
  public ClusterProvisionBuilder(ClusterProvisionFluent<?> fluent,ClusterProvision instance) {
    this(fluent, instance, false);
  }
  public ClusterProvisionBuilder(ClusterProvisionFluent<?> fluent,ClusterProvision instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterProvisionBuilder(ClusterProvision instance) {
    this(instance,false);
  }
  public ClusterProvisionBuilder(ClusterProvision instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ClusterProvisionFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterProvision build() {
    ClusterProvision buildable = new ClusterProvision(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
